==> tekton-model-triggers-v1alpha1-6.5.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerBindingFluentImpl<A extends TriggerBindingFluent<A>> extends BaseFluent<A> implements TriggerBindingFluent<A>{
  public TriggerBindingFluentImpl() {
  }
  public TriggerBindingFluentImpl(TriggerBinding instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerBindingSpecBuilder spec;
  private TriggerBindingStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerBindingFluent.MetadataNested<A> withNewMetadata() {
    return new TriggerBindingFluentImpl.MetadataNestedImpl();
  }
  public TriggerBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerBindingFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerBindingFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerBindingFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerBindingSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerBindingSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerBindingSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerBindingSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerBindingFluent.SpecNested<A> withNewSpec() {
    return new TriggerBindingFluentImpl.SpecNestedImpl();
  }
  public TriggerBindingFluent.SpecNested<A> withNewSpecLike(TriggerBindingSpec item) {
    return new TriggerBindingFluentImpl.SpecNestedImpl(item);
  }
  public TriggerBindingFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerBindingFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerBindingSpecBuilder().build());
  }
  public TriggerBindingFluent.SpecNested<A> editOrNewSpecLike(TriggerBindingSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerBindingStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerBindingStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerBindingStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerBindingStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerBindingFluent.StatusNested<A> withNewStatus() {
    return new TriggerBindingFluentImpl.StatusNestedImpl();
  }
  public TriggerBindingFluent.StatusNested<A> withNewStatusLike(TriggerBindingStatus item) {
    return new TriggerBindingFluentImpl.StatusNestedImpl(item);
  }
  public TriggerBindingFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerBindingFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerBindingStatusBuilder().build());
  }
  public TriggerBindingFluent.StatusNested<A> editOrNewStatusLike(TriggerBindingStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerBindingFluentImpl that = (TriggerBindingFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerBindingFluent.MetadataNested<N>> implements TriggerBindingFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerBindingSpecFluentImpl<TriggerBindingFluent.SpecNested<N>> implements TriggerBindingFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerBindingSpec item) {
      this.builder = new TriggerBindingSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerBindingSpecBuilder(this);
    }
    TriggerBindingSpecBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerBindingStatusFluentImpl<TriggerBindingFluent.StatusNested<N>> implements TriggerBindingFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerBindingStatus item) {
      this.builder = new TriggerBindingStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerBindingStatusBuilder(this);
    }
    TriggerBindingStatusBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerBindingFluentImpl<A extends TriggerBindingFluent<A>> extends BaseFluent<A> implements TriggerBindingFluent<A>{
  public TriggerBindingFluentImpl() {
  }
  public TriggerBindingFluentImpl(TriggerBinding instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerBindingSpecBuilder spec;
  private TriggerBindingStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerBindingFluentImpl.MetadataNested<A> withNewMetadata() {
    return new TriggerBindingFluentImpl.MetadataNestedImpl();
  }
  public TriggerBindingFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerBindingFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerBindingFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerBindingFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerBindingFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerBindingSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerBindingSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerBindingSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerBindingSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerBindingFluentImpl.SpecNested<A> withNewSpec() {
    return new TriggerBindingFluentImpl.SpecNestedImpl();
  }
  public TriggerBindingFluentImpl.SpecNested<A> withNewSpecLike(TriggerBindingSpec item) {
    return new TriggerBindingFluentImpl.SpecNestedImpl(item);
  }
  public TriggerBindingFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerBindingFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerBindingSpecBuilder().build());
  }
  public TriggerBindingFluentImpl.SpecNested<A> editOrNewSpecLike(TriggerBindingSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerBindingStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerBindingStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerBindingStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerBindingStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerBindingFluentImpl.StatusNested<A> withNewStatus() {
    return new TriggerBindingFluentImpl.StatusNestedImpl();
  }
  public TriggerBindingFluentImpl.StatusNested<A> withNewStatusLike(TriggerBindingStatus item) {
    return new TriggerBindingFluentImpl.StatusNestedImpl(item);
  }
  public TriggerBindingFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerBindingFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerBindingStatusBuilder().build());
  }
  public TriggerBindingFluentImpl.StatusNested<A> editOrNewStatusLike(TriggerBindingStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerBindingFluentImpl that = (TriggerBindingFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerBindingFluentImpl.MetadataNested<N>> implements TriggerBindingFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerBindingSpecFluentImpl<TriggerBindingFluentImpl.SpecNested<N>> implements TriggerBindingFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerBindingSpec item) {
      this.builder = new TriggerBindingSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerBindingSpecBuilder(this);
    }
    TriggerBindingSpecBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerBindingStatusFluentImpl<TriggerBindingFluentImpl.StatusNested<N>> implements TriggerBindingFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerBindingStatus item) {
      this.builder = new TriggerBindingStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerBindingStatusBuilder(this);
    }
    TriggerBindingStatusBuilder builder;
    public N and() {
      return (N) TriggerBindingFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
